#ifndef DEFINES_H
 #define DEFINES_H
 #include <defines.h>
#endif

void time_out(int signo);

#ifdef HAVE_UNISTD_H
# ifdef HAVE_FCNTL
struct flock* file_lock(short type, short whence);
void read_lock(int fd);
void write_lock(int fd);
void append_lock(int fd);
void unlock(int fd);  /* unlock */

# else /* Do nothing */
void file_lock(short type, short whence);
void read_lock(int fd);
void write_lock(int fd);
void append_lock(int fd);
void unlock(int fd);

# endif
#endif
